Skip to contents

A class that represents control devices, like the mouse or joystick.

Super class

ramiga::RamigaComponent -> RamigaControlDevice

Methods

Inherited methods


Method new()

Usage

RamigaControlDevice$new(emulator, port_number, type)

Arguments

emulator

A virtual control device only is meaningful when connected to a virtual device. Therefore, you need an emulator (RamigaEmulator) to connect the device to.

port_number

Port on the virtual machine to which the device is connected. Should be either port 1 or 2.

type

Type of device, should be either "mouse", or "joystick".


Method print()

Prints some basic information about the control device

Usage

RamigaControlDevice$print(...)

Arguments

...

Ignored


Method clone()

The objects of this class are cloneable with this method.

Usage

RamigaControlDevice$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.