A class that represents the emulator's Central Processing Unit (CPU).
Methods
Inherited methods
Method get_cycles()
Get the CPU cycle count since the emulator started
Returns
Returns the count in number of cycles
Method get_program_counter()
Get the memory address of the currently running program
Usage
RamigaCPU$get_program_counter()
Returns
On the Amiga memory addresses are mapped as 32 bit
unsigned integers. As R doesn't support this type, it is
returned as a numeric (double) value.
Method get_config()
Get current CPU configuration details
Returns
Returns a named list
Print some basic information about the CPU
Method clone()
The objects of this class are cloneable with this method.
Usage
RamigaCPU$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.