An abstract class to represent emulator components. Each of the emulator components inherit from this class. It provides consistent access to and control over component specific options.
Active bindings
optionsA named
listof options. You can get and set all individual elements. Elements are always returned ascharacter, but can be also be set asnumericorlogical, depending on the specific option. Assignment values are always parsed by the vAmiga engine.
Methods
Method new()
Most emulator components don't need to be initialised. It's simplest
to create an emulator with RamigaEmulator$new(). All components
can be accessed through the R6 object fields.
Usage
RamigaComponent$new(emulator, ...)Method get_emulator()
Get associated emulator.
Returns
Returns a RamigaEmulator class object instance in memory
Method list_options()
List available options for the emulator component. It shows the name of the option and indicates their intended value(s).