A class that represents control devices, like the mouse or joystick.
Super class
ramiga::RamigaComponent -> RamigaControlDevice
Methods
Method new()
Usage
RamigaControlDevice$new(emulator, port_number, type)Arguments
emulatorA virtual control device only is meaningful when connected to a virtual device. Therefore, you need an emulator (RamigaEmulator) to connect the device to.
port_numberPort on the virtual machine to which the device is connected. Should be either port 1 or 2.
typeType of device, should be either
"mouse", or"joystick".
Method print()
Prints some basic information about the control device