A class that represents the emulator's control ports (for mouse and joystick).
Super class
ramiga::RamigaComponent -> RamigaControlPort
Active bindings
deviceThis field tells you which device (mouse, joystick or none) is connected to the current port. Should be a RamigaControlDevice class object, or
NULLif there is no device.
Methods
Method new()
Usage
RamigaControlPort$new(emulator, port_number = 1L, device = NULL)Arguments
emulatorAn
RamigaEmulatorclass object. The control port to be created needs to be associated with a virtual machine. The initiated object will represent the control port of the emulated machine.port_numberThe Amiga has two control ports. This number specifies which one we are using. Should be either 1 or 2.
deviceDevice connected to this port. An RamigaControlDevice class object or
NULLif there is no device.
Method print()
Print some basic information about the control port.