A class representing the emulator for emulating an Amiga.
Super class
ramiga::RamigaComponent -> RamigaEmulator
Active bindings
memoryThe emulated memory, represented by RamigaMemory
cpuThe emulated CPU, represented by RamigaCPU
floppy_drivesThe emulated floppy drives, represented by a named
listof RamigaFloppyDrive objects.control_portsControl ports to which a virtual mouse or joystick can be connected. It is represented by the RamigaControlPort class.
outputGet object to capture emulator output. Handled by RamigaOutput.
Methods
Method power_on()
When the emulator is initialised it is powered off. Call this to power on the virtual machine.
Method power_off()
Power off emulator. Advisable if you plan to make adjustments to the emulated hardware configuration.
Method soft_reset()
A soft reset, just resets the CPU, causing the system to reboot.
This is similar to simultaneously pressing
Method run()
When initialised, the emulator is paused. Call this to start
running the virtual machine. It will hold up the R thread
untill you interrupt (by pressing
Method set_config()
Quickly set the emulator configuration to one of the pre-specified schemes.
Method print()
Prints basic information about the emulator.