A class that represents the emulator's floppy drive.
Super class
ramiga::RamigaComponent -> RamigaFloppyDrive
Methods
Method new()
Usage
RamigaFloppyDrive$new(emulator, drive_number = 0)Arguments
emulatorAn
RamigaEmulatorclass object. The floppy drive to be created needs to be associated with a virtual machine. The initiated object will represent the floppy drive of the emulated machine.drive_numberThe emulator has 4 floppy drives, numbered 0 to 3. Pick which drive you want to operate
Method insert_disk()
Insert a virtual floppy disk in the virtual floppy drive.
Arguments
diskA floppy disk represented by a RamigaImage class object.
write_protectedlogicalvalue indicating whether the inserted disk needs to be write protected. Default isTRUE
Method print()
Prints some basic information about the floppy drive