A virtual device represented by an image.
Methods
Method new()
Initialise an image from a disk image file.
Arguments
path
File pointing to disk image file.
Method info()
Get information about the image.
Returns
Returns a named list with information
Method size()
Get the size of the device represented by the image.
Returns
Returns the size of the image in bytes.
Method get_pointer()
Get the pointer to the image object in memory
Usage
RamigaImage$get_pointer(...)
Returns
Returns the externalptr pointing to the C++ class
instance in memory.
Determines if there is a file system present.
Usage
RamigaImage$is_formatted()
Returns
Returns logical indicating if disk contains a file system.
Method get_file_system()
Get a file system from a virtual device if present
Usage
RamigaImage$get_file_system(...)
Print some basic information about the device
Method clone()
The objects of this class are cloneable with this method.
Usage
RamigaImage$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.