A class to capture output from the Amiga emulator (RamigaEmulator class).
Super class
ramiga::RamigaComponent -> RamigaOutput
Methods
Method capture_video_frame()
Captures the current pixel information as sent to the monitor of the virtual device.
Returns
If file is missing it returns a grDevices::as.raster() object.
Otherwise, it will save it as png file to the specified path and returns
nothing.
Method capture_audio_buffer()
Capture the audio that is currently on the output buffer. While the emulator is running, audio is continuously generated and stored in a ring buffer. Use this function to collect data in this buffer. It can only be read once and the buffer has a limited capacity.
Returns
If file is omitted, the audio data is returned as
a matrix of numeric values. It returns 2 rows (for both
stereo channels). The number of columns correspond with the
number of samples available from the buffer. The waveform
is scaled between -1 and +1, such that it can be played
directly with audio::play().
Method print()
Prints basic information about the emulator output.