A class to capture output from the Amiga emulator (RamigaEmulator class).
Methods
Inherited methods
Method capture_frame()
Captures the current pixel information as sent to the monitor of
the virtual device.
Usage
RamigaOutput$capture_frame(file, ...)
Arguments
file
A path to a png file where to store the captured frame.
...
Ignored
Returns
If file is missing it returns a grDevice::as.raster() object.
Otherwise, it will save it as png file to the specified path and returns
nothing.
Method capture_audio_buffer()
TODO
Usage
RamigaOutput$capture_audio_buffer(file, ...)
Prints basic information about the emulator output.
Method clone()
The objects of this class are cloneable with this method.
Usage
RamigaOutput$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.